@@ -16,7 +16,7 @@ use GD::Polygon;
 
 use vars qw($VERSION @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS $AUTOLOAD);
 
-$VERSION = '2.61';
+$VERSION = '2.62';
 our $XS_VERSION = $VERSION;
 $VERSION = eval $VERSION;
 
@@ -65,6 +65,29 @@ $VERSION = eval $VERSION;
 # documentation error
 *GD::Polygon::delete = \&GD::Polygon::deletePt;
 
+sub AUTOLOAD {
+    # This AUTOLOAD is used to 'autoload' constants from the constant()
+    # XS function.  If a constant is not found then control is passed
+    # to the AUTOLOAD in AutoLoader.
+
+    my($constname);
+    ($constname = $AUTOLOAD) =~ s/.*:://;
+    undef $!;
+    my $val = constant($constname);
+    if ($! != 0) {
+       if ($! =~ /Invalid/) {
+           $AutoLoader::AUTOLOAD = $AUTOLOAD;
+           goto &AutoLoader::AUTOLOAD;
+       }
+       else {
+           my($pack,$file,$line) = caller;
+           die "Your vendor has not defined GD macro $pack\:\:$constname, used at $file line $line $!.\n";
+       }
+    }
+    eval "sub $AUTOLOAD { $val }";
+    goto &$AUTOLOAD;
+}
+
 bootstrap GD;
 
 
